@@ -28,7 +28,7 @@ class fillVars(object, cl_base.glob_attr):
         if not domain:
             print _("Error:") + " " +_("Not found domain name")
             print _("Command 'hostname -d' returns an empty value")
-            exit(1)
+            cl_base.exit(1)
         elif re.search("^hostname: ",domain):
             return "local"
         else:
